package com.mints.goodmoney;

import android.app.ActivityManager;
import android.content.Context;
import android.content.Intent;
import android.os.Build;
import android.text.TextUtils;
import android.webkit.WebView;

import androidx.localbroadcastmanager.content.LocalBroadcastManager;
import androidx.multidex.MultiDex;
import androidx.multidex.MultiDexApplication;

import com.bun.miitmdid.core.JLibrary;
import com.mints.goodmoney.common.Constant;
import com.mints.goodmoney.manager.ChannelManager;
import com.mints.goodmoney.manager.LiebaoManager;
import com.mints.goodmoney.manager.MhManager;
import com.mints.goodmoney.manager.MiitHelper;
import com.mints.goodmoney.manager.RsNewsManager;
import com.mints.goodmoney.manager.TtCsjAdManager;
import com.mints.goodmoney.manager.WnManager;
import com.mints.goodmoney.manager.YlVideoManager;
import com.mints.goodmoney.manager.YlhAdManager;
import com.mints.goodmoney.net.LoanService;
import com.mints.goodmoney.utils.ForegroundOrBackground;
import com.mints.goodmoney.utils.LogUtil;
import com.mints.goodmoney.utils.SystemUtils;

import java.util.concurrent.Executors;

import rx.Scheduler;
import rx.schedulers.Schedulers;

/**
 * 描述：Application
 * 作者：孟崔广
 * 时间：2020/10/09 11:40
 */
public class MintsApplication extends MultiDexApplication {

    private static MintsApplication mContext;
    public static String OAID = "";

    private static LocalBroadcastManager mLocalBroadcastManager;
    private Scheduler defaultSubscribeScheduler;

    private LoanService loanService;

    public static MintsApplication getContext() {
        return mContext;
    }

    @Override
    public void onCreate() {
        super.onCreate();
        mContext = this;
        // 判断应用是否在前台
        ForegroundOrBackground.init(this);

        // 三方配置
        thirdConfig();
    }

    private void androidPWebView() {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.P) {
            String processName = getProcessName(this);
            String packageName = this.getPackageName();
            if (!packageName.equals(processName)) {
                try {
                    // 为不同进程webView设置不同目录
                    WebView.setDataDirectorySuffix("dds_" + processName);
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        }
    }

    @Override
    public void onLowMemory() {
        android.os.Process.killProcess(android.os.Process.myPid());
        super.onLowMemory();
    }

    @Override
    protected void attachBaseContext(Context base) {
        super.attachBaseContext(base);
//        MultiDex.install(this);

        // 9.0之后不可多进程使用一个目录下的WebView，写在SDK初始化之前
        androidPWebView();

        // 移动安全联盟
        try {
            JLibrary.InitEntry(base);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 三方配置
     */
    private void thirdConfig() {
        // 移动安全联盟 oaid
        initMiitHelper();

        // 按渠道匹配代码位
        ChannelManager.INSTANCE.updataCodeIdForRegisterChannel(null);

        // 子线程初始化三方SDK
        String processName = SystemUtils.INSTANCE.getProcessName(this, android.os.Process.myPid());
        if (processName != null) {
            // 判断onCreate方法执行是否在当前应用的application上
            boolean defaultProcess = TextUtils.equals(processName, Constant.MINTS_PKG_NAME);
            if (defaultProcess) {
                InitAppService.Companion.start(this); //初始化数据
            }
        }

        // 优量汇
        YlhAdManager.INSTANCE.initYlhAd(this);

        // 穿山甲
        TtCsjAdManager.init(this);

        // 闪电盒子
        WnManager.INSTANCE.initWn(this);

        // 枫岚广告
        MhManager.INSTANCE.initWn(this);

        // 一览视频
        YlVideoManager.INSTANCE.init(this);

        // 猎豹游戏初始化
        LiebaoManager.getInstance().initCmGameSdk();

        // 瑞狮新闻
        RsNewsManager.INSTANCE.initX5Environment(this);
    }

    private MiitHelper.AppIdsUpdater appIdsUpdater = ids -> OAID = ids;

    /**
     * 移动安装联盟 获取OAID等设备标识符
     */
    private void initMiitHelper() {
        try {
            MiitHelper miitHelper = new MiitHelper(appIdsUpdater);
            miitHelper.initDeviceIds(getApplicationContext());
        } catch (Exception e) {
            e.printStackTrace();
            LogUtil.e(e);
        }
    }

    /**
     * app退出
     */
    public void exitApp() {
        Intent intent = new Intent();
        intent.setAction(Constant.ACTION_EXIT_APP);
        intent.addCategory(Intent.CATEGORY_DEFAULT);
        MintsApplication.getLocalBroadcastManager().sendBroadcast(intent);

        System.gc();
    }

    /**
     * 获得LocalBroadcastManager对象
     */
    public static LocalBroadcastManager getLocalBroadcastManager() {
        if (mLocalBroadcastManager == null) {
            mLocalBroadcastManager = LocalBroadcastManager.getInstance(mContext);
        }
        return mLocalBroadcastManager;
    }

    public LoanService getLoanService() {
        if (loanService == null) {
            loanService = LoanService.Factory.create();
        }
        return loanService;
    }

    public Scheduler defaultSubscribeScheduler() {
        if (defaultSubscribeScheduler == null) {
            defaultSubscribeScheduler = Schedulers.from(Executors.newFixedThreadPool(10));
        }
        return defaultSubscribeScheduler;
    }

    private String getProcessName(Context context) {
        if (context == null) return null;
        ActivityManager manager = (ActivityManager) context.getSystemService(Context.ACTIVITY_SERVICE);
        if (manager != null) {
            for (ActivityManager.RunningAppProcessInfo processInfo : manager.getRunningAppProcesses()) {
                if (processInfo.pid == android.os.Process.myPid()) {
                    return processInfo.processName;
                }
            }
        }
        return null;
    }

}
